==> gip-recia__actualites-1.0.0.jar: META-INF/resources/webjars/gip-recia__actualites/1.0.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [commit-and-tag-version](https://github.com/absolute-version/commit-and-tag-version) for commit guidelines.

## 1.0.0 (2025-03-17)


### ⚠ BREAKING CHANGES

* **actualites:** rebase to main
* **actualites:** rebase to main
* **actualites:** rebase to main

### build

* **actualites:** rebase to main ([e5c5a1e](https://github.com/GIP-RECIA/recia-webcomponents/commit/e5c5a1eba92410f89e8e656a8787e865427e6669))
* **actualites:** rebase to main ([1b2d296](https://github.com/GIP-RECIA/recia-webcomponents/commit/1b2d2962a19f02d134d00c5e9db4bb1a040d1e5a))
* **actualites:** rebase to main ([82e1203](https://github.com/GIP-RECIA/recia-webcomponents/commit/82e1203a4bf0fec549c53124ba66946712bb2feb))


### Features

* **actualites:** Accessibility - keybord control ([dc46d90](https://github.com/GIP-RECIA/recia-webcomponents/commit/dc46d9011725154f8cb7584653f647aa7bdde29e))
* **actualites:** Accessibility - keybord control ([6a6e32b](https://github.com/GIP-RECIA/recia-webcomponents/commit/6a6e32b94db4fc814a1d957197866107153845e1))
* **actualites:** add button and tag css ([63e98e3](https://github.com/GIP-RECIA/recia-webcomponents/commit/63e98e35596a056857217db5d5644b776037272f))
* **actualites:** add button tertiary ([20754c7](https://github.com/GIP-RECIA/recia-webcomponents/commit/20754c73b77d6dfab1045dc2f7d078c9989aa439))
* **actualites:** add card transition ([6deb52b](https://github.com/GIP-RECIA/recia-webcomponents/commit/6deb52b190947570113df78fcbb4e7e6f0cce90c))
* **actualites:** add source map ([f2df996](https://github.com/GIP-RECIA/recia-webcomponents/commit/f2df996c438e5aff28901369641bdaa5131a10d5))
* **actualites:** add tooltip more info to BottomSheet.ce.vue ([2593c29](https://github.com/GIP-RECIA/recia-webcomponents/commit/2593c296eb1aa8d1f3636c66461c9baa2f257e36))
* **actualites:** add urls ([bc9776e](https://github.com/GIP-RECIA/recia-webcomponents/commit/bc9776eb8773c7baba3aa4b784e1de2bf6693d5b))
* **actualites:** card image scale on hover/focus ([282cc46](https://github.com/GIP-RECIA/recia-webcomponents/commit/282cc46d0a2365fd15d931deb8ea4b990309a89b))
* **actualites:** Carrousel + affichage de toutes les actus ([93dfdca](https://github.com/GIP-RECIA/recia-webcomponents/commit/93dfdcaecdd2e54b84c06dee21e4c63220e4594a))
* **actualites:** change reading state only for connected peoples ([600be9e](https://github.com/GIP-RECIA/recia-webcomponents/commit/600be9e6ba5786b33aa89a0d66234d0364ea77f5))
* **actualites:** display carousel arrow only when content is available ([97d359f](https://github.com/GIP-RECIA/recia-webcomponents/commit/97d359fc8998555c15a458243edd6f89c63b175a))
* **actualites:** Mise en place du filtre de lecture ([f6d7082](https://github.com/GIP-RECIA/recia-webcomponents/commit/f6d7082a2f65d686e2561686f547520010707942))
* **actualites:** modal closable by esc ([d8e5d76](https://github.com/GIP-RECIA/recia-webcomponents/commit/d8e5d76eb40595b338ec5d49dfbd8d11e6e128c9))
* **actualites:** modifications toutes les actualités + modal actualités + corrections ([877dd86](https://github.com/GIP-RECIA/recia-webcomponents/commit/877dd862b381aca09c9e60cbf6b41f8e1e1a62dd))
* **actualites:** modifications toutes les actualités + modal actualités + corrections ([93fe630](https://github.com/GIP-RECIA/recia-webcomponents/commit/93fe630396eee526cd874867b30574d75126c3a5))
* **actualites:** no news message ([670b012](https://github.com/GIP-RECIA/recia-webcomponents/commit/670b0124d52ec4a2d6bd8c65bdca3774c5de6fd0))
* **actualites:** reset default style ([074b453](https://github.com/GIP-RECIA/recia-webcomponents/commit/074b45385b70930be3b445a990533709c8d52b0e))
* **actualites:** Responsivity update ([8f8bb3f](https://github.com/GIP-RECIA/recia-webcomponents/commit/8f8bb3f727dd0f161fbb8b76598af3edcad5a1ab))
* **actualites:** skeleton loading ([62ad76d](https://github.com/GIP-RECIA/recia-webcomponents/commit/62ad76d94873b3a2519a9b9e012eb3c7e1e39b59))
* **actualites:** use button primary circle on carousel ([2a9b919](https://github.com/GIP-RECIA/recia-webcomponents/commit/2a9b919f17491b9f48093ddc21f210cd4bf63348))
* **actualites:** use buttons style globally ([907e0a1](https://github.com/GIP-RECIA/recia-webcomponents/commit/907e0a1ec18d36b9f8f691620f1e13c89b5997a5))
* **actualites:** use props for URLs instead ([e6f9de8](https://github.com/GIP-RECIA/recia-webcomponents/commit/e6f9de8188524370156392d3f443b3bd75b12010))
* **actualites:** use proxy for local development ([7f853f0](https://github.com/GIP-RECIA/recia-webcomponents/commit/7f853f015a9e4421d1d862d8820000787dacd6b1))


### Bug Fixes

* **actualites:** add missing show all style ([4e283a5](https://github.com/GIP-RECIA/recia-webcomponents/commit/4e283a5744c2951d3df010df9786092d91c18512))
* **actualites:** all news back icon size ([76f0803](https://github.com/GIP-RECIA/recia-webcomponents/commit/76f080321c6cbccdbe6eb6ee744b0d1ef6845190))
* **actualites:** bottom sheet breakpoints ([f9e1c0f](https://github.com/GIP-RECIA/recia-webcomponents/commit/f9e1c0f3410c85e12363786d8182ead6deb2aad8))
* **actualites:** bottom sheet header image outline ([eb8a2e9](https://github.com/GIP-RECIA/recia-webcomponents/commit/eb8a2e9403e6eb8ed78a675e93bbae3203019dce))
* **actualites:** bottom sheet image header ([dc684eb](https://github.com/GIP-RECIA/recia-webcomponents/commit/dc684ebc1cb414327738ec39160c628aa4c06947))
* **actualites:** bottom sheet image size ([f9d7c15](https://github.com/GIP-RECIA/recia-webcomponents/commit/f9d7c15a24ff66660ba5c7c0a9c22b0892c2e5d6))
* **actualites:** bottom sheet loading ([4fb14ed](https://github.com/GIP-RECIA/recia-webcomponents/commit/4fb14ed211121a23b0e123190eef36b7c2feb711))
* **actualites:** bottom sheet opening ([973456d](https://github.com/GIP-RECIA/recia-webcomponents/commit/973456dd688d5966af1ea0aa192c3c0bd238af35))
* **actualites:** bottom sheet width ([8f5825b](https://github.com/GIP-RECIA/recia-webcomponents/commit/8f5825b7c006b230ee634ce64f01ca687a5f9da4))
* **actualites:** bottom sheet z-index ([d155be3](https://github.com/GIP-RECIA/recia-webcomponents/commit/d155be31711bc7a943946ddee53b2aa6b125821a))
* **actualites:** carousel arrows ([3794a53](https://github.com/GIP-RECIA/recia-webcomponents/commit/3794a53edaf2527450c7cb1a72208537b054eafe))
* **actualites:** changement de l'appel au composant BottomSheet de NewsCard.ce.vue vers AllNews.ce.vue. ([cefc4b2](https://github.com/GIP-RECIA/recia-webcomponents/commit/cefc4b28e6f800acbd4ac0062cb77c589f73b510))
* **actualites:** changement de l'appel au composant BottomSheet de NewsCard.ce.vue vers Carrousel ([6581a5e](https://github.com/GIP-RECIA/recia-webcomponents/commit/6581a5e1e999ac2490d2af1b0e3259e5912fe60b))
* **actualites:** corrections css + code refactor ([7b5377c](https://github.com/GIP-RECIA/recia-webcomponents/commit/7b5377cbf18a48b9783d5f61c491aa5fbec1ce61))
* **actualites:** en translation ([6b01c67](https://github.com/GIP-RECIA/recia-webcomponents/commit/6b01c67e44da3fc7f71a38f731e41defefe62fe7))
* **actualites:** fix card title hover ([0adc245](https://github.com/GIP-RECIA/recia-webcomponents/commit/0adc24555d87407370cd5aa32c3671a1d7f8ea6f))
* **actualites:** fix carrousel arrow ([1fd0b0f](https://github.com/GIP-RECIA/recia-webcomponents/commit/1fd0b0fb8386b2cd842b39375ee0123e5e0fd7d8))
* **actualites:** fix date format for bottomsheet-content-header-informations-item-autor ([20d8db9](https://github.com/GIP-RECIA/recia-webcomponents/commit/20d8db9ff9ae3ea08e02f8c3c26bf2662fd075e9))
* **actualites:** fix eslint error ([19496b2](https://github.com/GIP-RECIA/recia-webcomponents/commit/19496b2fee6965629e5f8a98e4d29ba5cedcc9de))
* **actualites:** fix font awesome icon usage ([35f2b21](https://github.com/GIP-RECIA/recia-webcomponents/commit/35f2b21ac5ac5e6759a480d410d88f39490c450c))
* **actualites:** fix footer disposition in modal ([49460d7](https://github.com/GIP-RECIA/recia-webcomponents/commit/49460d7e90e29bfcc4bf4925f7731b4772ea27e5))
* **actualites:** fix handle bar for firefox ([504eb29](https://github.com/GIP-RECIA/recia-webcomponents/commit/504eb291e4cb43eec795fc96d132119c78ffda71))
* **actualites:** fix left arrow from allNews title ([efb09e5](https://github.com/GIP-RECIA/recia-webcomponents/commit/efb09e58e2db494d32eb23c05bc4c83828d06de1))
* **actualites:** fix pagination ([d17b7fb](https://github.com/GIP-RECIA/recia-webcomponents/commit/d17b7fbb9e235dcc37dc07f4849c7d068a5a7a57))
* **actualites:** fix readingState change timer ([83c903a](https://github.com/GIP-RECIA/recia-webcomponents/commit/83c903a73e75d8d7066e2ca46a43e4fa56a73bb8))
* **actualites:** fix switch ([726e98c](https://github.com/GIP-RECIA/recia-webcomponents/commit/726e98ced1e9d30e92a6944c4256508f153bf029))
* **actualites:** fr translation ([2145ff6](https://github.com/GIP-RECIA/recia-webcomponents/commit/2145ff6400150198c1a94d6170d668f52f814501))
* **actualites:** improve css ([5981a28](https://github.com/GIP-RECIA/recia-webcomponents/commit/5981a288b65162fb4df7a2f4b12f005d4df6f917))
* **actualites:** no enclosure ([353d607](https://github.com/GIP-RECIA/recia-webcomponents/commit/353d60766957cb3c53073ec6d103dd3946adb20f))
* **actualites:** no enclosure ([b6aef07](https://github.com/GIP-RECIA/recia-webcomponents/commit/b6aef07893401c2bafc6b51c9f5527d31c5da827))
* **actualites:** page-selector default props ([f05bbff](https://github.com/GIP-RECIA/recia-webcomponents/commit/f05bbffaf0a5c623ff888b10439ff213265ef5dc))
* **actualites:** props links ([d6b8c48](https://github.com/GIP-RECIA/recia-webcomponents/commit/d6b8c48eccf38fe4d4a08ff0f55b287b9f91e574))
* **actualites:** props links ([0b659d2](https://github.com/GIP-RECIA/recia-webcomponents/commit/0b659d2aa06546ae713632e04b6dfb0706f3c4a1))
* **actualites:** rattrapage post deploy test ([05301a0](https://github.com/GIP-RECIA/recia-webcomponents/commit/05301a05f1214c79c140537f58b7a7788efeaae2))
* **actualites:** read style ([f15f0e8](https://github.com/GIP-RECIA/recia-webcomponents/commit/f15f0e88541af3a00c243959e7d6aa0e61d6fd13))
* **actualites:** remove fonts from build ([1220add](https://github.com/GIP-RECIA/recia-webcomponents/commit/1220addb60f42a8a6fb60bf605eff9092da88ad2))
* **actualites:** remove unused parameter that introduce bug ([bf22459](https://github.com/GIP-RECIA/recia-webcomponents/commit/bf2245993fa06bcaa76668338cfc7b3bdf3abcf3))
* **actualites:** scroll lock in portal ([df1404a](https://github.com/GIP-RECIA/recia-webcomponents/commit/df1404a1d43fad8277ea2c92cd12895b968452b9))
* **actualites:** shadows ([2fad855](https://github.com/GIP-RECIA/recia-webcomponents/commit/2fad8555b7833fd5a74cf8389403ea4ddc000d0a))
* **actualites:** toggle switch background ([ba71838](https://github.com/GIP-RECIA/recia-webcomponents/commit/ba71838156753da486c06cdce432319c7987263b))
* **actualites:** traductions + selection des rubriques + restriction scroll de la page principal lorsque la modal est ouverte ([3a097b1](https://github.com/GIP-RECIA/recia-webcomponents/commit/3a097b11ddde67441288db2abf38eef635f09402))
* **actualites:** use default color ([2d7f3a9](https://github.com/GIP-RECIA/recia-webcomponents/commit/2d7f3a99ccc55a52a6dbf38725ba0efc9c10b244))
* **actualites:** use em instead of rem ([54999ed](https://github.com/GIP-RECIA/recia-webcomponents/commit/54999ed6811723324921e76b9a74e86dd0a4a3bd))
* **actualites:** use h2 for carousel title ([cb16e9d](https://github.com/GIP-RECIA/recia-webcomponents/commit/cb16e9d20c308eadee54bbeab7fafecdd00970c5))
* **actualites:** use overflow to lock scroll when bottom sheet open ([cf15a78](https://github.com/GIP-RECIA/recia-webcomponents/commit/cf15a783ff0930aebfc1c3b9e36ab9f5583051ae))

==> gip-recia__actualites-1.1.0.jar: META-INF/resources/webjars/gip-recia__actualites/1.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [commit-and-tag-version](https://github.com/absolute-version/commit-and-tag-version) for commit guidelines.

## [1.1.0](https://github.com/GIP-RECIA/recia-webcomponents/compare/actualites/v1.0.1...actualites/v1.1.0) (2025-03-27)


### ⚠ BREAKING CHANGES

* **actualites:** remove base url and change API return types

### Features

* **actualites:** add bottom sheet loading error message ([73ea0a7](https://github.com/GIP-RECIA/recia-webcomponents/commit/73ea0a73d06ebb7961362099c157247aafaef62d))
* **actualites:** hides rubriques on loading ([898e528](https://github.com/GIP-RECIA/recia-webcomponents/commit/898e52820dc3e15f9682dcde11e389ba52ba2888))
* **actualites:** remove base url and change API return types ([af1618e](https://github.com/GIP-RECIA/recia-webcomponents/commit/af1618ee34e272d7078cbc29b1f06cf13e4df383))


### Bug Fixes

* **actualites:** add news body links ([93f8183](https://github.com/GIP-RECIA/recia-webcomponents/commit/93f81839cfb5ae69b57c39983d3df8a91782bbfd))

## [1.0.1](https://github.com/GIP-RECIA/recia-webcomponents/compare/actualites/v1.0.0...actualites/v1.0.1) (2025-03-18)


### Bug Fixes

* **actualites:** hide elements when no interaction is needed ([950ce76](https://github.com/GIP-RECIA/recia-webcomponents/commit/950ce76f55140081f507e4e18c5eb0aebff383d1))

## 1.0.0 (2025-03-17)


### ⚠ BREAKING CHANGES

* **actualites:** rebase to main
* **actualites:** rebase to main
* **actualites:** rebase to main

### build

* **actualites:** rebase to main ([e5c5a1e](https://github.com/GIP-RECIA/recia-webcomponents/commit/e5c5a1eba92410f89e8e656a8787e865427e6669))
* **actualites:** rebase to main ([1b2d296](https://github.com/GIP-RECIA/recia-webcomponents/commit/1b2d2962a19f02d134d00c5e9db4bb1a040d1e5a))
* **actualites:** rebase to main ([82e1203](https://github.com/GIP-RECIA/recia-webcomponents/commit/82e1203a4bf0fec549c53124ba66946712bb2feb))


### Features

* **actualites:** Accessibility - keybord control ([dc46d90](https://github.com/GIP-RECIA/recia-webcomponents/commit/dc46d9011725154f8cb7584653f647aa7bdde29e))
* **actualites:** Accessibility - keybord control ([6a6e32b](https://github.com/GIP-RECIA/recia-webcomponents/commit/6a6e32b94db4fc814a1d957197866107153845e1))
* **actualites:** add button and tag css ([63e98e3](https://github.com/GIP-RECIA/recia-webcomponents/commit/63e98e35596a056857217db5d5644b776037272f))
* **actualites:** add button tertiary ([20754c7](https://github.com/GIP-RECIA/recia-webcomponents/commit/20754c73b77d6dfab1045dc2f7d078c9989aa439))
* **actualites:** add card transition ([6deb52b](https://github.com/GIP-RECIA/recia-webcomponents/commit/6deb52b190947570113df78fcbb4e7e6f0cce90c))
* **actualites:** add source map ([f2df996](https://github.com/GIP-RECIA/recia-webcomponents/commit/f2df996c438e5aff28901369641bdaa5131a10d5))
* **actualites:** add tooltip more info to BottomSheet.ce.vue ([2593c29](https://github.com/GIP-RECIA/recia-webcomponents/commit/2593c296eb1aa8d1f3636c66461c9baa2f257e36))
* **actualites:** add urls ([bc9776e](https://github.com/GIP-RECIA/recia-webcomponents/commit/bc9776eb8773c7baba3aa4b784e1de2bf6693d5b))
* **actualites:** card image scale on hover/focus ([282cc46](https://github.com/GIP-RECIA/recia-webcomponents/commit/282cc46d0a2365fd15d931deb8ea4b990309a89b))
* **actualites:** Carrousel + affichage de toutes les actus ([93dfdca](https://github.com/GIP-RECIA/recia-webcomponents/commit/93dfdcaecdd2e54b84c06dee21e4c63220e4594a))
* **actualites:** change reading state only for connected peoples ([600be9e](https://github.com/GIP-RECIA/recia-webcomponents/commit/600be9e6ba5786b33aa89a0d66234d0364ea77f5))
* **actualites:** display carousel arrow only when content is available ([97d359f](https://github.com/GIP-RECIA/recia-webcomponents/commit/97d359fc8998555c15a458243edd6f89c63b175a))
* **actualites:** Mise en place du filtre de lecture ([f6d7082](https://github.com/GIP-RECIA/recia-webcomponents/commit/f6d7082a2f65d686e2561686f547520010707942))
* **actualites:** modal closable by esc ([d8e5d76](https://github.com/GIP-RECIA/recia-webcomponents/commit/d8e5d76eb40595b338ec5d49dfbd8d11e6e128c9))
* **actualites:** modifications toutes les actualités + modal actualités + corrections ([877dd86](https://github.com/GIP-RECIA/recia-webcomponents/commit/877dd862b381aca09c9e60cbf6b41f8e1e1a62dd))
* **actualites:** modifications toutes les actualités + modal actualités + corrections ([93fe630](https://github.com/GIP-RECIA/recia-webcomponents/commit/93fe630396eee526cd874867b30574d75126c3a5))
* **actualites:** no news message ([670b012](https://github.com/GIP-RECIA/recia-webcomponents/commit/670b0124d52ec4a2d6bd8c65bdca3774c5de6fd0))
* **actualites:** reset default style ([074b453](https://github.com/GIP-RECIA/recia-webcomponents/commit/074b45385b70930be3b445a990533709c8d52b0e))
* **actualites:** Responsivity update ([8f8bb3f](https://github.com/GIP-RECIA/recia-webcomponents/commit/8f8bb3f727dd0f161fbb8b76598af3edcad5a1ab))
* **actualites:** skeleton loading ([62ad76d](https://github.com/GIP-RECIA/recia-webcomponents/commit/62ad76d94873b3a2519a9b9e012eb3c7e1e39b59))
* **actualites:** use button primary circle on carousel ([2a9b919](https://github.com/GIP-RECIA/recia-webcomponents/commit/2a9b919f17491b9f48093ddc21f210cd4bf63348))
* **actualites:** use buttons style globally ([907e0a1](https://github.com/GIP-RECIA/recia-webcomponents/commit/907e0a1ec18d36b9f8f691620f1e13c89b5997a5))
* **actualites:** use props for URLs instead ([e6f9de8](https://github.com/GIP-RECIA/recia-webcomponents/commit/e6f9de8188524370156392d3f443b3bd75b12010))
* **actualites:** use proxy for local development ([7f853f0](https://github.com/GIP-RECIA/recia-webcomponents/commit/7f853f015a9e4421d1d862d8820000787dacd6b1))


### Bug Fixes

* **actualites:** add missing show all style ([4e283a5](https://github.com/GIP-RECIA/recia-webcomponents/commit/4e283a5744c2951d3df010df9786092d91c18512))
* **actualites:** all news back icon size ([76f0803](https://github.com/GIP-RECIA/recia-webcomponents/commit/76f080321c6cbccdbe6eb6ee744b0d1ef6845190))
* **actualites:** bottom sheet breakpoints ([f9e1c0f](https://github.com/GIP-RECIA/recia-webcomponents/commit/f9e1c0f3410c85e12363786d8182ead6deb2aad8))
* **actualites:** bottom sheet header image outline ([eb8a2e9](https://github.com/GIP-RECIA/recia-webcomponents/commit/eb8a2e9403e6eb8ed78a675e93bbae3203019dce))
* **actualites:** bottom sheet image header ([dc684eb](https://github.com/GIP-RECIA/recia-webcomponents/commit/dc684ebc1cb414327738ec39160c628aa4c06947))
* **actualites:** bottom sheet image size ([f9d7c15](https://github.com/GIP-RECIA/recia-webcomponents/commit/f9d7c15a24ff66660ba5c7c0a9c22b0892c2e5d6))
* **actualites:** bottom sheet loading ([4fb14ed](https://github.com/GIP-RECIA/recia-webcomponents/commit/4fb14ed211121a23b0e123190eef36b7c2feb711))
* **actualites:** bottom sheet opening ([973456d](https://github.com/GIP-RECIA/recia-webcomponents/commit/973456dd688d5966af1ea0aa192c3c0bd238af35))
* **actualites:** bottom sheet width ([8f5825b](https://github.com/GIP-RECIA/recia-webcomponents/commit/8f5825b7c006b230ee634ce64f01ca687a5f9da4))
* **actualites:** bottom sheet z-index ([d155be3](https://github.com/GIP-RECIA/recia-webcomponents/commit/d155be31711bc7a943946ddee53b2aa6b125821a))
* **actualites:** carousel arrows ([3794a53](https://github.com/GIP-RECIA/recia-webcomponents/commit/3794a53edaf2527450c7cb1a72208537b054eafe))
* **actualites:** changement de l'appel au composant BottomSheet de NewsCard.ce.vue vers AllNews.ce.vue. ([cefc4b2](https://github.com/GIP-RECIA/recia-webcomponents/commit/cefc4b28e6f800acbd4ac0062cb77c589f73b510))
* **actualites:** changement de l'appel au composant BottomSheet de NewsCard.ce.vue vers Carrousel ([6581a5e](https://github.com/GIP-RECIA/recia-webcomponents/commit/6581a5e1e999ac2490d2af1b0e3259e5912fe60b))
* **actualites:** corrections css + code refactor ([7b5377c](https://github.com/GIP-RECIA/recia-webcomponents/commit/7b5377cbf18a48b9783d5f61c491aa5fbec1ce61))
* **actualites:** en translation ([6b01c67](https://github.com/GIP-RECIA/recia-webcomponents/commit/6b01c67e44da3fc7f71a38f731e41defefe62fe7))
* **actualites:** fix card title hover ([0adc245](https://github.com/GIP-RECIA/recia-webcomponents/commit/0adc24555d87407370cd5aa32c3671a1d7f8ea6f))
* **actualites:** fix carrousel arrow ([1fd0b0f](https://github.com/GIP-RECIA/recia-webcomponents/commit/1fd0b0fb8386b2cd842b39375ee0123e5e0fd7d8))
* **actualites:** fix date format for bottomsheet-content-header-informations-item-autor ([20d8db9](https://github.com/GIP-RECIA/recia-webcomponents/commit/20d8db9ff9ae3ea08e02f8c3c26bf2662fd075e9))
* **actualites:** fix eslint error ([19496b2](https://github.com/GIP-RECIA/recia-webcomponents/commit/19496b2fee6965629e5f8a98e4d29ba5cedcc9de))
* **actualites:** fix font awesome icon usage ([35f2b21](https://github.com/GIP-RECIA/recia-webcomponents/commit/35f2b21ac5ac5e6759a480d410d88f39490c450c))
* **actualites:** fix footer disposition in modal ([49460d7](https://github.com/GIP-RECIA/recia-webcomponents/commit/49460d7e90e29bfcc4bf4925f7731b4772ea27e5))
* **actualites:** fix handle bar for firefox ([504eb29](https://github.com/GIP-RECIA/recia-webcomponents/commit/504eb291e4cb43eec795fc96d132119c78ffda71))
* **actualites:** fix left arrow from allNews title ([efb09e5](https://github.com/GIP-RECIA/recia-webcomponents/commit/efb09e58e2db494d32eb23c05bc4c83828d06de1))
* **actualites:** fix pagination ([d17b7fb](https://github.com/GIP-RECIA/recia-webcomponents/commit/d17b7fbb9e235dcc37dc07f4849c7d068a5a7a57))
* **actualites:** fix readingState change timer ([83c903a](https://github.com/GIP-RECIA/recia-webcomponents/commit/83c903a73e75d8d7066e2ca46a43e4fa56a73bb8))
* **actualites:** fix switch ([726e98c](https://github.com/GIP-RECIA/recia-webcomponents/commit/726e98ced1e9d30e92a6944c4256508f153bf029))
* **actualites:** fr translation ([2145ff6](https://github.com/GIP-RECIA/recia-webcomponents/commit/2145ff6400150198c1a94d6170d668f52f814501))
* **actualites:** improve css ([5981a28](https://github.com/GIP-RECIA/recia-webcomponents/commit/5981a288b65162fb4df7a2f4b12f005d4df6f917))
* **actualites:** no enclosure ([353d607](https://github.com/GIP-RECIA/recia-webcomponents/commit/353d60766957cb3c53073ec6d103dd3946adb20f))
* **actualites:** no enclosure ([b6aef07](https://github.com/GIP-RECIA/recia-webcomponents/commit/b6aef07893401c2bafc6b51c9f5527d31c5da827))
* **actualites:** page-selector default props ([f05bbff](https://github.com/GIP-RECIA/recia-webcomponents/commit/f05bbffaf0a5c623ff888b10439ff213265ef5dc))
* **actualites:** props links ([d6b8c48](https://github.com/GIP-RECIA/recia-webcomponents/commit/d6b8c48eccf38fe4d4a08ff0f55b287b9f91e574))
* **actualites:** props links ([0b659d2](https://github.com/GIP-RECIA/recia-webcomponents/commit/0b659d2aa06546ae713632e04b6dfb0706f3c4a1))
* **actualites:** rattrapage post deploy test ([05301a0](https://github.com/GIP-RECIA/recia-webcomponents/commit/05301a05f1214c79c140537f58b7a7788efeaae2))
* **actualites:** read style ([f15f0e8](https://github.com/GIP-RECIA/recia-webcomponents/commit/f15f0e88541af3a00c243959e7d6aa0e61d6fd13))
* **actualites:** remove fonts from build ([1220add](https://github.com/GIP-RECIA/recia-webcomponents/commit/1220addb60f42a8a6fb60bf605eff9092da88ad2))
* **actualites:** remove unused parameter that introduce bug ([bf22459](https://github.com/GIP-RECIA/recia-webcomponents/commit/bf2245993fa06bcaa76668338cfc7b3bdf3abcf3))
* **actualites:** scroll lock in portal ([df1404a](https://github.com/GIP-RECIA/recia-webcomponents/commit/df1404a1d43fad8277ea2c92cd12895b968452b9))
* **actualites:** shadows ([2fad855](https://github.com/GIP-RECIA/recia-webcomponents/commit/2fad8555b7833fd5a74cf8389403ea4ddc000d0a))
* **actualites:** toggle switch background ([ba71838](https://github.com/GIP-RECIA/recia-webcomponents/commit/ba71838156753da486c06cdce432319c7987263b))
* **actualites:** traductions + selection des rubriques + restriction scroll de la page principal lorsque la modal est ouverte ([3a097b1](https://github.com/GIP-RECIA/recia-webcomponents/commit/3a097b11ddde67441288db2abf38eef635f09402))
* **actualites:** use default color ([2d7f3a9](https://github.com/GIP-RECIA/recia-webcomponents/commit/2d7f3a99ccc55a52a6dbf38725ba0efc9c10b244))
* **actualites:** use em instead of rem ([54999ed](https://github.com/GIP-RECIA/recia-webcomponents/commit/54999ed6811723324921e76b9a74e86dd0a4a3bd))
* **actualites:** use h2 for carousel title ([cb16e9d](https://github.com/GIP-RECIA/recia-webcomponents/commit/cb16e9d20c308eadee54bbeab7fafecdd00970c5))
* **actualites:** use overflow to lock scroll when bottom sheet open ([cf15a78](https://github.com/GIP-RECIA/recia-webcomponents/commit/cf15a783ff0930aebfc1c3b9e36ab9f5583051ae))
